/* $Id: sofi_dfs.c,v 1.12 2013-03-12 08:04:54 llundin Exp $
 *
 * This file is part of the SOFI Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
 */

/*
 * $Author: llundin $
 * $Date: 2013-03-12 08:04:54 $
 * $Revision: 1.12 $
 * $Name: not supported by cvs2svn $
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

/*-----------------------------------------------------------------------------
   								Includes
 -----------------------------------------------------------------------------*/

#include <string.h>
#include <math.h>

#include <cpl.h>

#include "sofi_dfs.h"

/*----------------------------------------------------------------------------*/
/**
 * @defgroup sofi_dfs  DFS related functions
 *
 * TBD
 */
/*----------------------------------------------------------------------------*/

/**@{*/

/*----------------------------------------------------------------------------*/
/**
  @brief    Set the group as RAW or CALIB in a frameset
  @param    set     the input frameset
  @return   0 if ok, -1 in error case
 */
/*----------------------------------------------------------------------------*/
int sofi_dfs_set_groups(cpl_frameset * set)
{
    cpl_frame   *   cur_frame ;
    const char  *   tag ;
    int             nframes ;
    int             i ;

    /* Check entries */
    if (set == NULL) return -1 ; 
    
    /* Initialize */
    nframes = cpl_frameset_get_size(set) ;

    /* Loop on frames */
    for (i=0 ; i<nframes ; i++) {
        cur_frame = cpl_frameset_get_position(set, i) ;
        tag = cpl_frame_get_tag(cur_frame) ;
       
        /* RAW frames */
        if (!strcmp(tag, SOFI_IMG_ZPOINT_RAW) || 
                !strcmp(tag, SOFI_IMG_DOMEFLAT_RAW) ||
                !strcmp(tag, SOFI_IMG_DARK_RAW) ||
                !strcmp(tag, SOFI_IMG_JITTER_SKY_RAW) ||
                !strcmp(tag, SOFI_IMG_JITTER_OBJ_RAW) ||
                !strcmp(tag, SOFI_IMG_DETLIN_LAMP_RAW) ||
                !strcmp(tag, SOFI_IMG_DETLIN_DARK_RAW) ||
                !strcmp(tag, SOFI_SPC_FLAT_RAW) ||
                !strcmp(tag, SOFI_SPC_ARC_RAW) ||
                !strcmp(tag, SOFI_SPC_JITTER_NODOBJ_RAW) ||
                !strcmp(tag, SOFI_SPC_JITTER_NODSKY_RAW) ||
                !strcmp(tag, SOFI_IMG_ILLUM_RAW) ||
                !strcmp(tag, SOFI_UTIL_GENLINES_RAW) ||
                !strcmp(tag, SOFI_UTIL_STDSTARS_RAW))
            cpl_frame_set_group(cur_frame, CPL_FRAME_GROUP_RAW) ;
        /* CALIB frames */
        else if (!strcmp(tag, SOFI_CALIB_FLAT) ||
                !strcmp(tag, SOFI_CALIB_STDSTARS) ||
                !strcmp(tag, SOFI_CALPRO_OH_CAT) ||
                !strcmp(tag, SOFI_CALPRO_XE_CAT) ||
                !strcmp(tag, SOFI_CALPRO_NE_CAT) ||
                !strcmp(tag, SOFI_CALIB_DARK) ||
                !strcmp(tag, SOFI_CALIB_DETLIN_A) ||
                !strcmp(tag, SOFI_CALIB_DETLIN_B) ||
                !strcmp(tag, SOFI_CALIB_DETLIN_C) ||
                !strcmp(tag, SOFI_CALIB_SPFLAT) ||
                !strcmp(tag, SOFI_CALIB_ARC))
            cpl_frame_set_group(cur_frame, CPL_FRAME_GROUP_CALIB) ;
    }
    return 0 ;
}

/**@}*/
